pub unsafe extern "C" fn folk_install_output_handler()Expand description
Install our output capture handler into the embed SAPI module.
Only needed for legacy embed SAPI (boot()), not for custom SAPI.
pub unsafe extern "C" fn folk_install_output_handler()Install our output capture handler into the embed SAPI module.
Only needed for legacy embed SAPI (boot()), not for custom SAPI.